; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.


;-| Super Motions |--------------------------------------------------------
[Command];Hyper Beam3
name = "HB3"
command = ~D, DF, F, D, DF, F, z
time = 30

[Command];Hyper Beam2
name = "HB2"
command = ~D, DF, F, D, DF, F, y
time = 30

[Command];Hyper Beam1
name = "HB1"
command = ~D, DF, F, D, DF, F, x
time = 30
[Command]
name = "cyber_death"
command = F, D, F, a+b
time = 30

[Command]
name = "Beam_Orb_A"
command = ~D, DF, F, D, DF, F, a
time = 30 

[Command]
name = "Beam_Orb_B"
command = ~D, DF, F, D, DF, F, b
time = 30 

[Command]
name = "Beam_Orb_C"
command = ~D, DF, F, D, DF, F, c
time = 30 

[Command]
name = "SCK_A"
command = ~D, DB, B, D, DB, B, a
time = 30 

[Command]
name = "SCK_B"
command = ~D, DB, B, D, DB, B, b
time = 30 

[Command]
name = "SCK_C"
command = ~D, DB, B, D, DB, B, c
time = 30 

;-| Special Motions |------------------------------------------------------

[Command]
name = "cyber_uppercut_x"
command = ~F, D, DF, x

[Command]
name = "cyber_uppercut_y"
command = ~F, D, DF, y

[Command]
name = "cyber_uppercut_z"
command = ~F, D, DF, z

[Command]
name = "knee_dash_a"
command = ~F, D, DF, a

[Command]
name = "knee_dash_b"
command = ~F, D, DF, b

[Command]
name = "knee_dash_c"
command = ~F, D, DF, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

[Command]
name = "QCF_X"
command = ~D, DF, F, x

[Command]
name = "QCF_Y"
command = ~D, DF, F, y

[Command]
name = "QCF_Z"
command = ~D, DF, F, z

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1


;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "start_1"
command = a+b
time = 1


;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV...
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Run Back
;'ރ_bV...
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand_Throw2
[State -1]
type = ChangeState
value = 920
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "fwd_z";Command
trigger2 = command = "fwd_z";Command
trigger3 = command = "fwd_z";Near
trigger3 = p2bodydist X < 5
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "fwd_z";Near
trigger4 = p2bodydist X < 5
trigger4 = p2statetype = C
trigger4 = p2movetype != H
trigger5 = command = "fwd_z";Near
trigger5 = p2bodydist X < 5
trigger5 = p2statetype = S
trigger5 = p2movetype != H
trigger6 = command = "fwd_z";Near
trigger6 = p2bodydist X < 5
trigger6 = p2statetype = C
trigger6 = p2movetype != H

;Super_Cyber_Kick_A
[State -1]
type = ChangeState
value = 1900
triggerall = command = "SCK_A"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 40      ;Jumpstart
trigger3 = stateno = 400     ;crouch_a
trigger4 = stateno = 430     ;crouch_x
trigger4 = movecontact = 1
trigger5 = stateno = 440     ;crouch_y
trigger5 = movecontact = 1
trigger6 = stateno = 450     ;crouch_z
trigger6 = movecontact = 1
trigger7 = stateno = 200     ;stand_a
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;Super_Cyber_Kick_B
[State -1]
type = ChangeState
value = 1900
triggerall = command = "SCK_B"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 40      ;Jumpstart
trigger3 = stateno = 400     ;crouch_a
trigger4 = stateno = 430     ;crouch_x
trigger4 = movecontact = 1
trigger5 = stateno = 440     ;crouch_y
trigger5 = movecontact = 1
trigger6 = stateno = 450     ;crouch_z
trigger6 = movecontact = 1
trigger7 = stateno = 200     ;stand_a
trigger7 = movecontact = 1


;---------------------------------------------------------------------------
;Super_Cyber_Kick_C
[State -1]
type = ChangeState
value = 1900
triggerall = command = "SCK_C"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 40      ;Jumpstart
trigger3 = stateno = 400     ;crouch_a
trigger4 = stateno = 430     ;crouch_x
trigger4 = movecontact = 1
trigger5 = stateno = 440     ;crouch_y
trigger5 = movecontact = 1
trigger6 = stateno = 450     ;crouch_z
trigger6 = movecontact = 1
trigger7 = stateno = 200     ;stand_a
trigger7 = movecontact = 1


;---------------------------------------------------------------------------
;Hyper Beam3
[State -1]
type = ChangeState
value = 3000
triggerall = command = "HB3"
triggerall = power >= 3000 ;Level 1 super
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 410
;---------------------------------------------------------------------------
; Hyper Beam2
[State -1]
type = ChangeState
value = 2025
triggerall = command = "HB2"
triggerall = power >= 2000 ;Level 1 super
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger3 = stateno = 200 
trigger4 = stateno = 610
trigger5 = stateno = 640
trigger6 = stateno = 670 
trigger7 = stateno = 600
trigger8 = stateno = 630 
trigger8 = stateno = 661 
trigger9 = stateno = 230
trigger10 = stateno = 240
trigger11 = stateno = 250 
trigger12 = stateno = 400
trigger13 = stateno = 410 
trigger14 = stateno = 420
trigger15 = stateno = 430
trigger16 = stateno = 440 
trigger17 = stateno = 450
trigger18= stateno = 630 
trigger19 = stateno = 1300
trigger20 = stateno = 1250
trigger21 = stateno = 1005
trigger22 = stateno = 1060 
trigger23 = stateno = 60 
trigger24 = stateno = 590
trigger25 = stateno = 1400
trigger26 = stateno = 3400
trigger27 = stateno = 9950
trigger28 = stateno = 4100

;---------------------------------------------------------------------------
; Hyper Beam1
[State -1]
type = ChangeState
value = 4020
triggerall = command = "HB1"
triggerall = power >= 3000 ;Level 3 super
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA

;---------------------------------------------------------------------------
;Beam Orb
[State -1]
type = ChangeState
value = 3020
triggerall=command= "Beam_Orb_A"
triggerall = numproj = 0
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = stateno = 200
trigger3 = stateno = 205
trigger4 = stateno = 206
trigger5 = stateno = 216
trigger6 = stateno = 215
trigger7 = stateno = 210
trigger8 = stateno = 400
trigger9 = stateno = 405
trigger10 = stateno = 406
trigger11 = stateno = 416
trigger12 = stateno = 415
trigger13 = stateno = 410


;---------------------------------------------------------------------------
;Beam Orb
[State -1]
type = ChangeState
value = 3020
triggerall=command= "Beam_Orb_B"
triggerall = numproj = 0
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = stateno = 200
trigger3 = stateno = 205
trigger4 = stateno = 206
trigger5 = stateno = 216
trigger6 = stateno = 215
trigger7 = stateno = 210
trigger8 = stateno = 400
trigger9 = stateno = 405
trigger10 = stateno = 406
trigger11 = stateno = 416
trigger12 = stateno = 415
trigger13 = stateno = 410

;---------------------------------------------------------------------------
;Beam Orb
[State -1]
type = ChangeState
value = 3020
triggerall=command= "Beam_Orb_C"
triggerall = numproj = 0
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger1 = statetype = S
trigger2 = stateno = 200
trigger3 = stateno = 205
trigger4 = stateno = 206
trigger5 = stateno = 216
trigger6 = stateno = 215
trigger7 = stateno = 210
trigger8 = stateno = 400
trigger9 = stateno = 405
trigger10 = stateno = 406
trigger11 = stateno = 416
trigger12 = stateno = 415
trigger13 = stateno = 410


; Super Air Hadoken 1
[State -1]
type = ChangeState
value = 1801
triggerall = PalNo < 7
triggerall = Var(20) = 0
triggerall = command = "HB1"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = movecontact 
trigger2 = (stateno = [600,699]) || (stateno = 1005)

; Super Air Hadoken 2
[State -1]
type = ChangeState
value = 1801
triggerall = PalNo < 7
triggerall = Var(20) = 0
triggerall = command = "HB2"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = movecontact 
trigger2 = (stateno = [600,699]) || (stateno = 1005)

; Super Air Hadoken 3
[State -1]
type = ChangeState
value = 1802
triggerall = PalNo < 7
triggerall = Var(20) = 0
triggerall = command = "HB3"
triggerall = power >= 2000 ;Level 2
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = movecontact 
trigger2 = (stateno = [600,699]) || (stateno = 1005)

;---------------------------------------------------------------------------
; Cyber Death
[State -1]
type = ChangeState
value = 4900
triggerall = command = "cyber_death"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger3 = stateno = 201
trigger4 = stateno = 202
trigger5 = stateno = 203
trigger6 = stateno = 204
trigger7 = stateno = 205
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = stateno = 301
trigger17 = stateno = 302
trigger18 = stateno = 304
trigger19 = stateno = 305
trigger20 = stateno = 306
trigger21 = stateno = 500
trigger22 = stateno = 550
trigger23 = movecontact = 1
trigger23 = stateno = 1100
trigger24 = movecontact = 1
trigger24 = stateno = 1110
trigger25 = movecontact = 1
trigger25 = stateno = 1120
trigger26 = movecontact = 1
trigger26 = stateno = 1050
trigger27 = movecontact = 1
trigger27 = stateno = 1060
trigger28 = movecontact = 1
trigger28 = stateno = 1070
trigger29 = movecontact = 1
trigger29 = stateno = 3000
trigger30 = movecontact = 1
trigger30 = stateno = 3010
trigger31 = movecontact = 1
trigger31 = stateno = 3020
trigger32 = projcontact = 1
trigger32 = stateno = 1010
trigger33 = projcontact = 1
trigger33 = stateno = 1011
trigger34 = projcontact = 1
trigger34 = stateno = 1012
trigger35 = projcontact = 1
trigger35 = stateno = 1000
trigger36 = projcontact = 1
trigger36 = stateno = 1001
trigger37 = projcontact = 1
trigger37 = stateno = 1002
trigger38 = movecontact = 1
trigger38 = stateno = 900
trigger39 = movecontact = 1
trigger39 = stateno = 910
trigger40 = movecontact = 1
trigger40 = stateno = 920
trigger41 = movecontact = 1
trigger41 = stateno = 945
trigger42 = stateno = 100
trigger43 = stateno = 950
trigger44 = stateno = 951
trigger45 = stateno = 952
;---------------------------------------------------------------------------
; Cyber Uppercut (X)
[State -1]
type = ChangeState
value = 2020
triggerall = command = "cyber_uppercut_x"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 210        ;stand_b
trigger2 = movecontact = 1
trigger3 = stateno = 420        ;crouch_z
trigger3 = movecontact = 1
trigger4 = stateno = 450        ;crouch_c
trigger4 = movecontact = 1

;---------------------------------------------------------------------------
; Cyber Uppercut (Y)
[State -1]
type = ChangeState
value = 2030
triggerall = command = "cyber_uppercut_y"
trigger1 = statetype != A
trigger1 = ctrl = 1             
trigger2 = stateno = 200        ;stand_x    
trigger2 = movecontact = 1                  
trigger3 = stateno = 400        ;crouch_a
trigger3 = movecontact = 1
trigger4 = stateno = 210        ;stand_b
trigger4 = movecontact = 1
trigger5 = stateno = 410        ;crouch_c
trigger5 = movecontact = 1
trigger6 = stateno = 500        ;crouch_fwd_a
trigger6 = movecontact = 1
trigger7 = stateno = 1052       ;flykick_b3
trigger7 = movecontact = 1
trigger8 = stateno = 450        ;crouch_z
trigger8 = movecontact = 1
trigger9 = stateno = 430        ;crouch_x
trigger9 = movecontact = 1

;---------------------------------------------------------------------------
; Cyber Uppercut (Z)
[State -1]
type = ChangeState
value = 2040
triggerall = command = "cyber_uppercut_z"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200        ;stand_x
trigger2 = movecontact = 1
trigger3 = stateno = 400        ;crouch_a
trigger3 = movecontact = 1
trigger4 = stateno = 210        ;stand_b
trigger4 = movecontact = 1
trigger5 = stateno = 410        ;crouch_b
trigger5 = movecontact = 1
trigger6 = stateno = 500        ;crouch_fwd_a
trigger6 = movecontact = 1
trigger7 = stateno = 450        ;crouch_z
trigger7 = movecontact = 1
trigger8 = stateno = 430        ;crouch_x
trigger8 = movecontact = 1

;Hadoken X
[State -1]
type = ChangeState
value = 1200
triggerall = command = "QCF_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 301
trigger17 = movecontact = 1
trigger17 = stateno = 302
trigger18 = movecontact = 1
trigger18 = stateno = 304
trigger19 = movecontact = 1
trigger19 = stateno = 305
trigger20 = stateno = 100
trigger21 = statetype = C
trigger21 = ctrl = 1
trigger22 = movecontact = 1
trigger22 = stateno = 306
trigger23 = movecontact = 1
trigger23 = stateno = 500
trigger24 = movecontact = 1
trigger24 = stateno = 550


;---------------------------------------------------------------------------
; Hadoken Y
[State -1]
type = ChangeState
value = 1210
triggerall = command = "QCF_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 301
trigger17 = movecontact = 1
trigger17 = stateno = 302
trigger18 = movecontact = 1
trigger18 = stateno = 304
trigger19 = movecontact = 1
trigger19 = stateno = 305
trigger20 = stateno = 100
trigger21 = statetype = C
trigger21 = ctrl = 1
trigger22 = movecontact = 1
trigger22 = stateno = 306
trigger23 = movecontact = 1
trigger23 = stateno = 500
trigger24 = movecontact = 1
trigger24 = stateno = 550

;---------------------------------------------------------------------------
; Hadoken Z
[State -1]
type = ChangeState
value = 1220
triggerall = command = "QCF_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 301
trigger17 = movecontact = 1
trigger17 = stateno = 302
trigger18 = movecontact = 1
trigger18 = stateno = 304
trigger19 = movecontact = 1
trigger19 = stateno = 305
trigger20 = stateno = 100
trigger21 = statetype = C
trigger21 = ctrl = 1
trigger22 = movecontact = 1
trigger22 = stateno = 306
trigger23 = movecontact = 1
trigger23 = stateno = 500
trigger24 = movecontact = 1
trigger24 = stateno = 550

; Cyber Dash Kick (light)
[State -1]
type = ChangeState
value = 1000
triggerall = command = "QCB_a"
triggerall = command != "holddown"
triggerall = var(2) = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno >= 200 ;ARRR1 added
trigger2 = stateno <= 240
trigger2 = stateno != 210
trigger2 = stateno != 220
trigger2 = movecontact = 1
trigger3 = stateno >= 400 ;ARRR1 added
trigger3 = stateno <= 450
trigger3 = stateno != 420
trigger3 = movecontact = 1

; Cyber Dash Kick (medium)
[State -1]
type = ChangeState
value = 1010
triggerall = command = "QCB_b"
triggerall = command != "holddown"
triggerall = var(2) = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno >= 200 ;ARRR1 added
trigger2 = stateno <= 240
trigger2 = stateno != 210
trigger2 = stateno != 220
trigger2 = movecontact = 1
trigger3 = stateno >= 400 ;ARRR1 added
trigger3 = stateno <= 450
trigger3 = stateno != 420
trigger3 = movecontact = 1

; Cyber Dash Kick (hard)
[State -1]
type = ChangeState
value = 1020
triggerall = command = "QCB_c"
triggerall = command != "holddown"
triggerall = var(2) = 0
triggerall = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno >= 200 ;ARRR1 added
trigger2 = stateno <= 240
trigger2 = stateno != 210
trigger2 = stateno != 220
trigger2 = movecontact = 1
trigger3 = stateno >= 400 ;ARRR1 added
trigger3 = stateno <= 450
trigger3 = stateno != 420
trigger3 = movecontact = 1

; Air Hadoken x
[State -1]
type = ChangeState
value = 1300
triggerall = command = "QCF_X"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = movecontact = 1
trigger6 = stateno = 605
trigger7 = movecontact = 1
trigger7 = stateno = 606
trigger8 = movecontact = 1
trigger8 = stateno = 704
trigger9 = movecontact = 1
trigger9 = stateno = 705
trigger10 = movecontact = 1
trigger10 = stateno = 706
trigger11 = stateno = 550
trigger12 = stateno = 800
trigger13 = movecontact = 1
trigger13 = stateno = 3520

;---------------------------------------------------------------------------
; Air hadoken Y
[State -1]
type = ChangeState
value = 1301
triggerall = command = "QCF_Y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = movecontact = 1
trigger6 = stateno = 605
trigger7 = movecontact = 1
trigger7 = stateno = 606
trigger8 = movecontact = 1
trigger8 = stateno = 704
trigger9 = movecontact = 1
trigger9 = stateno = 705
trigger10 = movecontact = 1
trigger10 = stateno = 706
trigger11 = stateno = 550
trigger12 = stateno = 800
trigger13 = movecontact = 1
trigger13 = stateno = 3520

;---------------------------------------------------------------------------
; Air Hadoken Z
[State -1]
type = ChangeState
value = 1302
triggerall = command = "QCF_Z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = movecontact = 1
trigger6 = stateno = 605
trigger7 = movecontact = 1
trigger7 = stateno = 606
trigger8 = movecontact = 1
trigger8 = stateno = 704
trigger9 = movecontact = 1
trigger9 = stateno = 705
trigger10 = movecontact = 1
trigger10 = stateno = 706
trigger11 = stateno = 550
trigger12 = stateno = 800
trigger13 = movecontact = 1
trigger13 = stateno = 3520


;===========================================================================
;---------------------------------------------------------------------------
; X Punch
;-p"`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 7

;---------------------------------------------------------------------------
; Y Punch
;-p"`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
; Z Punch
;-p"`
[State -1, Stand Strong Punch]
type = ChangeState
value = 250
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6
;---------------------------------------------------------------------------
; A Kick
;-LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
; B Kick
;-LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
; C Kick
[State -1]
type = ChangeState
value = 260
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 201
trigger2 = movecontact = 1  
trigger3 = stateno = 200
trigger3 = movecontact = 1  
trigger4 = stateno = 210
trigger4 = movecontact = 1  
trigger5 = stateno = 211
trigger5 = movecontact = 1  
trigger6 = stateno = 212
trigger6 = movecontact = 1  


;---------------------------------------------------------------------------
;Taunt C
[State -1]
type = ChangeState
value = 199
triggerall = command = "start"
triggerall = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 100


;---------------------------------------------------------------------------
;Taunt B
[State -1]
type = ChangeState
value = 198
triggerall = command = "start"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 100

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
; X Duck Punch
;Ⴊݎp"`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Y Duck Punch
;Ⴊ݋p"`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Duck Punch Z
[State -1]
type = ChangeState
value = 450
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 404
trigger5 = movecontact = 1
trigger5 = stateno = 405
trigger6 = movecontact = 1
trigger6 = stateno = 200
trigger7 = movecontact = 1
trigger7 = stateno = 201
trigger8 = movecontact = 1
trigger8 = stateno = 204
trigger9 = movecontact = 1
trigger9 = stateno = 205
trigger10 = movecontact = 1
trigger10 = stateno = 207
trigger11 = movecontact = 1
trigger11 = stateno = 208
trigger12 = stateno = 100
trigger13 = movecontact = 1
trigger13 = stateno = 304
trigger14 = movecontact = 1
trigger14 = stateno = 301
trigger15 = movecontact = 1
trigger15 = stateno = 305
;---------------------------------------------------------------------------
; A Duck Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
; B Duck Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)
;---------------------------------------------------------------------------
; C Duck Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 470
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
; X Jump Punch
;'p"`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7

;---------------------------------------------------------------------------
; Y Jump Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
; Z Jump Punch
;'LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
; A Jump Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; B Jump Kick
;'LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact

;---------------------------------------------------------------------------
; C Jump Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 660
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
